# UC3M-PIC

![Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Framajoballester%2FUC3M-PIC%2Fmain%2Fpyproject.toml&style=flat-square)

Computer Vision class material for Master in Robotics and Automation at UC3M

# Installation

Refer to the installation guide for your OS

## Install pytorch 2.0 and its dependencies

Follow Pytorch official [installation guide](https://pytorch.org/get-started/locally/).
Installation with conda is highly recommended.

## Install uc3m-pic package

Clone this repo in your working directory:

```git clone https://github.com/ramajoballester/UC3M-PIC.git```

And install it:

```pip install .```

To check everything is working, run:

```python -m unittest```


# Usage

Do not forget to run `wandb login` before starting the kernels of notebooks 02 and 03
